@@ -39,12 +39,12 @@ int main (int argc, char **argv)
     auto aboutData = KAboutData {
         QStringLiteral("kronometer"),   // componentName
         i18nc("KAboutData display name", "Kronometer"),
-        QStringLiteral("2.1.3"),    // version
+        QStringLiteral("2.1.4"),    // version
         i18n("Kronometer is a simple stopwatch application"), // shortDescription
         KAboutLicense::GPL_V2,    // licenseType
         i18n("Copyright (C) 2014-2016 Elvis Angelaccio"),    // copyrightStatement
         {},  // otherText
-        QStringLiteral("https://eang.it/kronometer")   // homePageAddress
+        QStringLiteral("https://userbase.kde.org/Kronometer")   // homePageAddress
     };
 
     aboutData.addAuthor(
